Codec

Enum Codec 

pub enum Codec {
Show 20 variants Ed25519Pub, Ed25519Priv, X25519Pub, X25519Priv, Secp256k1Pub, Secp256k1Priv, P256Pub, P256Priv, P384Pub, P384Priv, P521Pub, P521Priv, MlDsa44Pub, MlDsa44PrivSeed, MlDsa65Pub, MlDsa65PrivSeed, MlDsa87Pub, MlDsa87PrivSeed, SlhDsaSha2_128sPub, Unknown(u64),
}
Known codec types

Variants



Ed25519Pub



Ed25519Priv



X25519Pub



X25519Priv



Secp256k1Pub



Secp256k1Priv



P256Pub



P256Priv



P384Pub



P384Priv



P521Pub



P521Priv



MlDsa44Pub



MlDsa44PrivSeed



MlDsa65Pub



MlDsa65PrivSeed



MlDsa87Pub



MlDsa87PrivSeed



SlhDsaSha2_128sPub



Unknown(u64)

Implementations

Source

impl Codec

pub fn from_u64(value: u64) -> Codec

Convert a raw codec value to a Codec enum

pub fn to_u64(self) -> u64

Convert to raw u64 value

pub fn is_public(&self) -> bool

Returns true if this is a public key codec

pub fn expected_key_length(&self) -> Option<usize>

Returns the expected key length for this codec, if known